@@ -60,10 +60,6 @@ struct _TotemPluginManagerPrivate
 	GtkTreeModel	*plugin_model;
 
 	GtkWidget	*configure_button;
-	GtkWidget	*site_label;
-	GtkWidget	*copyright_label;
-	GtkWidget	*authors_label;
-	GtkWidget	*description_label;
 	GtkWidget	*header_hbox;
 	GtkWidget	*plugin_icon;
 	GtkWidget	*site_text;
@@ -191,10 +187,12 @@ cursor_changed_cb (GtkTreeSelection *selection,
 		/* rescale icon to fit header if needed */
 		GdkPixbuf *icon_scaled;
 		gint width, height, header_height;
+		GtkAllocation allocation;
 
 		width = gdk_pixbuf_get_width (icon);
 		height = gdk_pixbuf_get_height (icon);
-		header_height = pm->priv->header_hbox->allocation.height;
+		gtk_widget_get_allocation (pm->priv->header_hbox, &allocation);
+		header_height = allocation.height;
 		if (height > header_height) {
 			icon_scaled = gdk_pixbuf_scale_simple (icon, 
 							       (gfloat)width/height*header_height, header_height,
@@ -503,15 +501,6 @@ totem_plugin_manager_init (TotemPluginManager *pm)
 	pm->priv->header_hbox = GTK_WIDGET (gtk_builder_get_object (xml, "header_hbox"));
 	pm->priv->plugin_title = GTK_WIDGET (gtk_builder_get_object (xml, "plugin_title"));
 
-	pm->priv->site_label = GTK_WIDGET (gtk_builder_get_object (xml, "site_label"));
-	totem_interface_boldify_label (xml, "site_label");
-	pm->priv->copyright_label = GTK_WIDGET (gtk_builder_get_object (xml, "copyright_label"));
-	totem_interface_boldify_label (xml, "copyright_label");
-	pm->priv->authors_label = GTK_WIDGET (gtk_builder_get_object (xml, "authors_label"));
-	totem_interface_boldify_label (xml, "authors_label");
-	pm->priv->description_label = GTK_WIDGET (gtk_builder_get_object (xml, "description_label"));
-	totem_interface_boldify_label (xml, "description_label");
-
 	pm->priv->plugin_icon = GTK_WIDGET (gtk_builder_get_object (xml, "plugin_icon"));
 	pm->priv->site_text = GTK_WIDGET (gtk_builder_get_object (xml, "site_text"));
 	pm->priv->copyright_text = GTK_WIDGET (gtk_builder_get_object (xml, "copyright_text"));
